%mach's cone

function mach

%Ratio of speed of object creating waves to wave speed (Mach number)
M = 3;

%%

%Number of time intervals
N = 10;

%Number of plot points for circular disturbances
P = 1000;
theta = linspace(0,2*pi,P);

%Compute Mach cone angle
alpha = asin(1/M);
if isreal( alpha ) == 0
    alpha = NaN;
end

%Initialize figure and axes
figure('name','Mach construction','color',[1,1,1] );
axes('Nextplot','add');
axis equal
grid on
box on
axis off
title( ['v/c = ',num2str(M),'.  sin^{-1}(c/v) = ',num2str(180*alpha/pi),'^o' ],'fontsize',12 );

%Interpolate colormap
interp_colormap(N);
cmap = colormap;

    %Plot circular wave disturbances
for n=1:N
    x = (1/M)*(N-n)*cos(theta) + N - n ;
    y = (1/M)*(N-n)*sin(theta);
    plot(x,y,'linewidth',2,'color', cmap(n,:) );  
    plot( N - n, 0, 'marker','*','color', cmap(n,:) );
end

%Overlay Mach cone
if isnan(alpha) == 0
    plot([0,N-1],[0,N-1]*tan(alpha),'k--','linewidth',2);
    plot([0,N-1],-[0,N-1]*tan(alpha),'k--','linewidth',2);
end

%Print figure and then close
print(gcf,['mach construction M=',strrep(num2str(M),'.','p')],'-dpng','-r300' );
close(gcf);

%%

%interp_colormap
% Function which interpolates current colourmap to yield better graduated
% shading. N is number of possible colours.
function interp_colormap( N )

%Get current colourmap
map = colormap;

%Initialise new colormap
new_map = ones(N,3);

%Get size of current colormap and initalise red,green,blue vectors
dim = size(map);
R = ones(1,dim(1));
G = ones(1,dim(1));
B = ones(1,dim(1));
RR = ones(1,N);
GG = ones(1,N);
BB = ones(1,N);

%Populate these with current colormap
R(:) = map(:,1);
G(:) = map(:,2);
B(:) = map(:,3);

%Interpolate to yield new colour map
x = linspace( 1, dim(1), N );
RR = interp1( 1:dim(1), R, x );
GG = interp1( 1:dim(1), G, x );
BB = interp1( 1:dim(1), B, x );
new_map(:,1) = RR(:);
new_map(:,2) = GG(:);
new_map(:,3) = BB(:);

%Set colormap to be new map
colormap( new_map );

%End of code