% Ripple phase velocity
% Andy French. August 2013.

rho = 1000;         % Density of water /kg/m^-3
sigma = 0.0728;     % Surface tension of water / Nm^-1  (Wolfram alpha)
g = 9.81;           % Gravitational field strength /ms^-2

N = 1000;
fsize = 12;
lamda = linspace(0,0.1,N);    %Wavelength /m
k = 2*pi./lamda;            %Wavenumber

%Ripple phase velocity (well, deep water interfacial waves) /ms^-1
c_p = sqrt( sigma*k/rho + g./k );

%Plot phase velocity
figure('name','deep water wave phase velocity','color',[1 1 1])
plot( 100*lamda, 100*c_p, 'linewidth',2 );
xlabel('\lambda /cm','fontsize',fsize)
ylabel('Phase velocity /cms^{-1}','fontsize',fsize)
title( 'Deep water wave phase velocity','fontsize',fsize)
ylim([0,100])
xlim([0,5])
set(gca,'fontsize',fsize)
grid on
print( gcf, 'ripples','-dpng','-r300')
close(gcf);

%End of code
